@@ -3,9 +3,9 @@
 #' @export
 #' @template all
 #' @template return
-#' @param dbname (charcter) Database name. Required.
-#' @param docid (charcter) Document ID. Required.
-#' @param attname (charcter) Attachment name. Optional.
+#' @param dbname (character) Database name. Required.
+#' @param docid (character) Document ID. Required.
+#' @param attname (character) Attachment name. Optional.
 #' @examples \dontrun{
 #' (x <- Cushion$new())
 #'
@@ -18,6 +18,6 @@ attach_get <- function(cushion, dbname, docid, attname = NULL, as = 'list', ...)
   } else {
     url <- file.path(cushion$make_url(), dbname, docid, attname)
   }
-  sofa_GET(url, as, content_type_json(), query = list(`_attachments` = "true"),
-           cushion$get_headers(), ...)
+  sofa_GET(url, as, query = list(`_attachments` = "true"),
+           cushion$get_headers(), cushion$get_auth(), ...)
 }
