@@ -13,5 +13,5 @@
 membership <- function(cushion, as = 'list', ...) {
   check_cushion(cushion)
   sofa_GET(file.path(cushion$make_url(), '_membership'),
-           as = as, cushion$get_headers(), ...)
+           as = as, cushion$get_headers(), cushion$get_auth(), ...)
 }
