@@ -1,10 +1,10 @@
-#' Ping a couchdb server
+#' Ping a CouchDB server
 #'
 #' @export
 #' @template all
 #' @template return
 #' @examples \dontrun{
-#' # initialize a couchdb connection
+#' # initialize a CouchDB connection
 #' (x <- Cushion$new())
 #'
 #' ping(x)
@@ -12,5 +12,6 @@
 #' }
 ping <- function(cushion, as = 'list', ...) {
   check_cushion(cushion)
-  sofa_GET(cushion$make_url(), as = as, args = NULL, cushion$get_headers(), ...)
+  sofa_GET(cushion$make_url(), as = as, args = NULL, cushion$get_headers(),
+           cushion$get_auth(), ...)
 }
