@@ -11,5 +11,5 @@
 restart <- function(cushion = "localhost", as = 'list', ...) {
   check_cushion(cushion)
   sofa_POST(file.path(cushion$make_url(), "_restart"),
-            as = as, cushion$get_headers(), ...)
+            as = as, cushion$get_headers(), cushion$get_auth(), ...)
 }
