@@ -14,5 +14,6 @@
 uuids <- function(cushion, count = 1, as = 'list', ...) {
   check_cushion(cushion)
   sofa_GET(file.path(cushion$make_url(), '_uuids'),
-           as = as, query = list(count = count), cushion$get_headers(), ...)
+           as = as, query = list(count = count), cushion$get_headers(),
+           cushion$get_auth(), ...)
 }
